==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/MachineLearning/AmazonSageMakerNotebook.md <==
# AmazonSageMakerNotebook


```text
aws-20210730/Resource/MachineLearning/AmazonSageMakerNotebook
```

```text
include('aws-20210730/Resource/MachineLearning/AmazonSageMakerNotebook')
```



| Illustration | AmazonSageMakerNotebook | AmazonSageMakerNotebookCard | AmazonSageMakerNotebookGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/MachineLearning/AmazonSageMakerNotebook.png) | ![illustration for AmazonSageMakerNotebook](../../../aws-20210730/Resource/MachineLearning/AmazonSageMakerNotebook.Local.png) | ![illustration for AmazonSageMakerNotebookCard](../../../aws-20210730/Resource/MachineLearning/AmazonSageMakerNotebookCard.Local.png) | ![illustration for AmazonSageMakerNotebookGroup](../../../aws-20210730/Resource/MachineLearning/AmazonSageMakerNotebookGroup.Local.png) |




## AmazonSageMakerNotebook

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSageMakerNotebook
include('aws-20210730/Resource/MachineLearning/AmazonSageMakerNotebook')

' renders the element
AmazonSageMakerNotebook('AmazonSageMakerNotebook', 'Amazon Sage Maker Notebook', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSageMakerNotebook
include('aws-20210730/Resource/MachineLearning/AmazonSageMakerNotebook')

' renders the element
AmazonSageMakerNotebook('AmazonSageMakerNotebook', 'Amazon Sage Maker Notebook', 'an optional tech label')
@enduml
```

## AmazonSageMakerNotebookCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSageMakerNotebookCard
include('aws-20210730/Resource/MachineLearning/AmazonSageMakerNotebook')

' renders the element
AmazonSageMakerNotebookCard('AmazonSageMakerNotebookCard', 'Amazon Sage Maker Notebook Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSageMakerNotebookCard
include('aws-20210730/Resource/MachineLearning/AmazonSageMakerNotebook')

' renders the element
AmazonSageMakerNotebookCard('AmazonSageMakerNotebookCard', 'Amazon Sage Maker Notebook Card', 'an optional description')
@enduml
```

## AmazonSageMakerNotebookGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSageMakerNotebookGroup
include('aws-20210730/Resource/MachineLearning/AmazonSageMakerNotebook')

' renders the element
AmazonSageMakerNotebookGroup('AmazonSageMakerNotebookGroup', 'Amazon Sage Maker Notebook Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSageMakerNotebookGroup
include('aws-20210730/Resource/MachineLearning/AmazonSageMakerNotebook')

' renders the element
AmazonSageMakerNotebookGroup('AmazonSageMakerNotebookGroup', 'Amazon Sage Maker Notebook Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/MachineLearning/AmazonSageMakerNotebook.md <==
# AmazonSageMakerNotebook


```text
aws-20210730/Resource/MachineLearning/AmazonSageMakerNotebook
```

```text
include('aws-20210730/Resource/MachineLearning/AmazonSageMakerNotebook')
```



| Illustration | AmazonSageMakerNotebook | AmazonSageMakerNotebookCard | AmazonSageMakerNotebookGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/MachineLearning/AmazonSageMakerNotebook.png) | ![illustration for AmazonSageMakerNotebook](../../../aws-20210730/Resource/MachineLearning/AmazonSageMakerNotebook.Local.png) | ![illustration for AmazonSageMakerNotebookCard](../../../aws-20210730/Resource/MachineLearning/AmazonSageMakerNotebookCard.Local.png) | ![illustration for AmazonSageMakerNotebookGroup](../../../aws-20210730/Resource/MachineLearning/AmazonSageMakerNotebookGroup.Local.png) |




## AmazonSageMakerNotebook

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSageMakerNotebook
include('aws-20210730/Resource/MachineLearning/AmazonSageMakerNotebook')

' renders the element
AmazonSageMakerNotebook('AmazonSageMakerNotebook', 'Amazon Sage Maker Notebook', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSageMakerNotebook
include('aws-20210730/Resource/MachineLearning/AmazonSageMakerNotebook')

' renders the element
AmazonSageMakerNotebook('AmazonSageMakerNotebook', 'Amazon Sage Maker Notebook', 'an optional tech label')
@enduml
```

## AmazonSageMakerNotebookCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSageMakerNotebookCard
include('aws-20210730/Resource/MachineLearning/AmazonSageMakerNotebook')

' renders the element
AmazonSageMakerNotebookCard('AmazonSageMakerNotebookCard', 'Amazon Sage Maker Notebook Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSageMakerNotebookCard
include('aws-20210730/Resource/MachineLearning/AmazonSageMakerNotebook')

' renders the element
AmazonSageMakerNotebookCard('AmazonSageMakerNotebookCard', 'Amazon Sage Maker Notebook Card', 'an optional description')
@enduml
```

## AmazonSageMakerNotebookGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSageMakerNotebookGroup
include('aws-20210730/Resource/MachineLearning/AmazonSageMakerNotebook')

' renders the element
AmazonSageMakerNotebookGroup('AmazonSageMakerNotebookGroup', 'Amazon Sage Maker Notebook Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSageMakerNotebookGroup
include('aws-20210730/Resource/MachineLearning/AmazonSageMakerNotebook')

' renders the element
AmazonSageMakerNotebookGroup('AmazonSageMakerNotebookGroup', 'Amazon Sage Maker Notebook Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
